#[repr(i32)]pub enum ErrorCode {
Show 23 variants
Success = 0,
ConnectionTimeout = 1_001,
InvalidAddress = 1_002,
LeaderChanged = 1_003,
JoinError = 1_004,
InvalidResponse = 2_001,
VersionMismatch = 2_002,
DiskFull = 3_001,
DataCorruption = 3_002,
StorageIoError = 3_003,
StoragePermissionDenied = 3_004,
KeyNotExist = 3_005,
NotLeader = 4_001,
StaleOperation = 4_002,
InvalidRequest = 4_003,
RateLimited = 4_004,
ClusterUnavailable = 4_005,
ProposeFailed = 4_006,
TermOutdated = 4_007,
RetryRequired = 4_008,
WatchBufferOverflow = 5_001,
General = 8_888,
Uncategorized = 9_999,
}Expand description
Client-facing error codes — transport-agnostic, mirrors proto ErrorCode.
Values are intentionally kept in sync with proto so that server-layer
conversions (core::ErrorCode ↔ proto::ErrorCode) are trivial numeric casts.
If a new variant is added here, add it to proto’s .proto file too.
Variants
Success = 0
ConnectionTimeout = 1_001
InvalidAddress = 1_002
LeaderChanged = 1_003
JoinError = 1_004
InvalidResponse = 2_001
VersionMismatch = 2_002
DiskFull = 3_001
DataCorruption = 3_002
StorageIoError = 3_003
StoragePermissionDenied = 3_004
KeyNotExist = 3_005
NotLeader = 4_001
StaleOperation = 4_002
InvalidRequest = 4_003
RateLimited = 4_004
ProposeFailed = 4_006
TermOutdated = 4_007
RetryRequired = 4_008
WatchBufferOverflow = 5_001
General = 8_888
Uncategorized = 9_999