StandaloneEngine

Struct StandaloneEngine 

pub struct StandaloneEngine;
Standalone d-engine engine for independent deployment

Implementations

Source

impl StandaloneEngine

pub async fn run( data_dir: impl AsRef<Path>, shutdown_rx: Receiver<()>, ) -> Result<(), Error>

Run server with an explicit data directory.

data_dir has highest priority and always overrides cluster.db_root_dir from CONFIG_PATH or RAFT__ environment variables. Other configuration (network, Raft timeouts, cluster topology) is still read from those sources if set.

The directory is created automatically if it does not exist. Blocks until shutdown signal is received.

Arguments
  • data_dir - Path to the data directory
  • shutdown_rx - Shutdown signal receiver
Example
let (shutdown_tx, shutdown_rx) = watch::channel(());
StandaloneEngine::run("./data/my-node", shutdown_rx).await?;
pub async fn run_with( config_path: &str, shutdown_rx: Receiver<()>, ) -> Result<(), Error>

Run server with explicit configuration file.

Reads configuration from specified file path. Data directory is determined by config’s cluster.db_root_dir setting. Blocks until shutdown signal is received.

Arguments
  • config_path - Path to configuration file
  • shutdown_rx - Shutdown signal receiver
Example
let (shutdown_tx, shutdown_rx) = watch::channel(());
StandaloneEngine::run_with("config/node1.toml", shutdown_rx).await?;
pub async fn run_custom<SE, SM>( storage_engine: Arc<SE>, state_machine: Arc<SM>, shutdown_rx: Receiver<()>, config_path: Option<&str>, ) -> Result<(), Error>
where SE: StorageEngine + Debug + 'static, SM: StateMachine + Debug + 'static,

Run server with custom storage engine and state machine.

Advanced API for users providing custom storage implementations. Blocks until shutdown signal is received.

Arguments
  • config - Node configuration
  • storage_engine - Custom storage engine implementation
  • state_machine - Custom state machine implementation
  • shutdown_rx - Shutdown signal receiver
Example
let storage = Arc::new(MyCustomStorage::new()?);
let sm = Arc::new(MyCustomStateMachine::new()?);

let (shutdown_tx, shutdown_rx) = watch::channel(());
StandaloneEngine::run_custom(storage, sm, shutdown_rx, Some("config.toml")).await?;